Django Sidebar
==============

Django sidebar is a dynamic sidebar creation for Django.

Easily create and manage sidebar from Django Admin with drag and drop interface and sidebar widget ordering.

Requirement
------------
Django 1.3+

Installation
------------
From pypi::

    $ pip install django-sidebar

or::

    $ easy_install django-sidebar

or clone from github::

    $ git clone git://github.com/ekaputra07/django-sidebar.git

or::

    $ cd django-sidebar
    $ sudo python setup.py install

Usage
-----
For more detail about the usage, please refer to the Django-sidebar documentation_.

.. _documentation: https://django-sidebar.readthedocs.org/